@@ -9,12 +9,12 @@ import numpy as np
 from img2table.tables.objects.extraction import ExtractedTable
 from img2table.tables.objects.line import Line
 from img2table.tables.objects.table import Table
+from img2table.tables.processing.bordered_tables.cells import get_cells
+from img2table.tables.processing.bordered_tables.lines import detect_lines
+from img2table.tables.processing.bordered_tables.tables import get_tables
+from img2table.tables.processing.bordered_tables.tables.implicit_rows import handle_implicit_rows
 from img2table.tables.processing.borderless_tables import detect_borderless_tables
-from img2table.tables.processing.cells import get_cells
-from img2table.tables.processing.lines import detect_lines
 from img2table.tables.processing.prepare_image import prepare_image
-from img2table.tables.processing.tables import get_tables
-from img2table.tables.processing.tables.implicit_rows import handle_implicit_rows
 from img2table.tables.processing.text.titles import get_title_tables
 
 
@@ -48,14 +48,22 @@ class TableImage:
         :param borderless_tables: boolean indicating if borderless tables should be detected
         :return: list of identified tables
         """
+        # If an OCR is provided, compute parameters base on it
+        if self.ocr_df is not None:
+            minLinLength = maxLineGap = round(0.75 * self.ocr_df.text_size or self.dpi // 20)
+            kernel_size = round(1.5 * self.ocr_df.text_size or self.dpi // 10)
+        else:
+            minLinLength = maxLineGap = self.dpi // 20
+            kernel_size = self.dpi // 10
+
         # Detect lines in image
         h_lines, v_lines = detect_lines(image=self.img,
                                         rho=0.3,
                                         theta=np.pi / 180,
                                         threshold=10,
-                                        minLinLength=self.dpi // 20,
-                                        maxLineGap=self.dpi // 20,
-                                        kernel_size=self.dpi // 10,
+                                        minLinLength=minLinLength,
+                                        maxLineGap=maxLineGap,
+                                        kernel_size=kernel_size,
                                         ocr_df=self.ocr_df)
         self.lines = h_lines + v_lines
 
